==> theme_tailor-1.0.1.tar.gz: lib/src/model/theme_encoder_data.dart <==
import 'package:theme_tailor/src/model/field.dart';

class ThemeEncoderData {
  const ThemeEncoderData(
    this.accessString,
    this.type,
    this.lerpAddExclamation,
  );

  factory ThemeEncoderData.className(
    String className,
    String accessor,
    String type,
  ) {
    final accessString = 'const $className${_withAccessor(accessor)}()';
    return ThemeEncoderData(accessString, type, false);
  }

  factory ThemeEncoderData.propertyAccess(
    String accessString,
    String type,
  ) {
    return ThemeEncoderData(accessString, type, false);
  }

  final String accessString;
  final String type;
  final bool lerpAddExclamation;

  String callLerp(String a, String b, String t) =>
      '$accessString.lerp($a, $b, $t)${_withExclamation(lerpAddExclamation)}';

  static String _withExclamation(bool withExclamation) =>
      withExclamation ? '!' : '';

  static String _withAccessor(String accessor) =>
      accessor.isEmpty ? '' : '.$accessor';

  @override
  String toString() =>
      'accesStr: $accessString, lerpReturnsNullable: $lerpAddExclamation';
}

class _AnyEncoder extends ThemeEncoderData {
  const _AnyEncoder._(
    super.accessString,
    super.type,
    super.lerpAddExclamation,
  );

  static _AnyEncoder instance = const _AnyEncoder._('', '', true);

  @override
  String callLerp(String a, String b, String t) => '$t < 0.5? $a : $b';
}

class ThemeEncoderDataManager {
  const ThemeEncoderDataManager._(this.typeToEncoder, this.fieldNameToEncoder);

  factory ThemeEncoderDataManager(
    Map<String, ThemeEncoderData> typeToEncoder,
    Map<String, ThemeEncoderData> fieldNameToEncoder,
  ) {
    final encoders = {
      ..._defaultEncoders,
      ...typeToEncoder,
    };
    return ThemeEncoderDataManager._(encoders, fieldNameToEncoder);
  }

  static const _color = ThemeEncoderData('Color', 'Color', true);
  static const _colorNull = ThemeEncoderData('Color', 'Color?', false);
  static const _tStyle = ThemeEncoderData('TextStyle', 'TextStyle', true);
  static const _tStyleNull = ThemeEncoderData('TextStyle', 'TextStyle?', false);

  static const _defaultEncoders = {
    'Color': _color,
    'Color?': _colorNull,
    'TextStyle': _tStyle,
    'TextStyle?': _tStyleNull,
  };

  final Map<String, ThemeEncoderData> typeToEncoder;
  final Map<String, ThemeEncoderData> fieldNameToEncoder;

  ThemeEncoderData encoderFromField(Field field) {
    return fieldNameToEncoder[field.name] ??
        typeToEncoder[field.typeStr] ??
        _AnyEncoder.instance;
  }
}

==> theme_tailor-1.0.3.tar.gz: lib/src/model/theme_encoder_data.dart <==
import 'package:theme_tailor/src/model/field.dart';

class ThemeEncoderData {
  const ThemeEncoderData(
    this.accessString,
    this.type,
    this.lerpAddExclamation,
  );

  factory ThemeEncoderData.className(
    String className,
    String accessor,
    String type,
  ) {
    final accessString = 'const $className${_withAccessor(accessor)}()';
    return ThemeEncoderData(accessString, type, false);
  }

  factory ThemeEncoderData.propertyAccess(
    String accessString,
    String type,
  ) {
    return ThemeEncoderData(accessString, type, false);
  }

  final String accessString;
  final String type;
  final bool lerpAddExclamation;

  String callLerp(String a, String b, String t) =>
      '$accessString.lerp($a, $b, $t)${_withExclamation(lerpAddExclamation)}';

  static String _withExclamation(bool withExclamation) =>
      withExclamation ? '!' : '';

  static String _withAccessor(String accessor) =>
      accessor.isEmpty ? '' : '.$accessor';

  @override
  String toString() =>
      'accesStr: $accessString, lerpReturnsNullable: $lerpAddExclamation';
}

class _AnyEncoder extends ThemeEncoderData {
  const _AnyEncoder._(
    super.accessString,
    super.type,
    super.lerpAddExclamation,
  );

  static _AnyEncoder instance = const _AnyEncoder._('', '', true);

  @override
  String callLerp(String a, String b, String t) => '$t < 0.5? $a : $b';
}

class ThemeEncoderDataManager {
  const ThemeEncoderDataManager._(this.typeToEncoder, this.fieldNameToEncoder);

  factory ThemeEncoderDataManager(
    Map<String, ThemeEncoderData> typeToEncoder,
    Map<String, ThemeEncoderData> fieldNameToEncoder,
  ) {
    final encoders = {
      ..._defaultEncoders,
      ...typeToEncoder,
    };
    return ThemeEncoderDataManager._(encoders, fieldNameToEncoder);
  }

  static const _color = ThemeEncoderData('Color', 'Color', true);
  static const _colorNull = ThemeEncoderData('Color', 'Color?', false);
  static const _tStyle = ThemeEncoderData('TextStyle', 'TextStyle', true);
  static const _tStyleNull = ThemeEncoderData('TextStyle', 'TextStyle?', false);

  static const _defaultEncoders = {
    'Color': _color,
    'Color?': _colorNull,
    'TextStyle': _tStyle,
    'TextStyle?': _tStyleNull,
  };

  final Map<String, ThemeEncoderData> typeToEncoder;
  final Map<String, ThemeEncoderData> fieldNameToEncoder;

  ThemeEncoderData encoderFromField(Field field) {
    return fieldNameToEncoder[field.name] ??
        typeToEncoder[field.typeName] ??
        _AnyEncoder.instance;
  }
}
